@@ -4,7 +4,7 @@ use 5.010;
 use Moo 1.004005;
 use namespace::autoclean;
 
-our $VERSION = '1.009001';
+our $VERSION = '1.010000';
 
 use HTTP::Headers ();
 use HTTP::Request ();
@@ -13,7 +13,7 @@ use LWP::UserAgent;
 use Scalar::Util qw( blessed );
 use Sub::Quote qw( quote_sub );
 use Try::Tiny qw( catch try );
-use Types::Standard qw( InstanceOf );
+use Types::Standard qw( Defined InstanceOf );
 use URI ();
 use WebService::MinFraud::Error::Generic;
 use WebService::MinFraud::Error::HTTP;
@@ -22,8 +22,13 @@ use WebService::MinFraud::Model::Factors;
 use WebService::MinFraud::Model::Insights;
 use WebService::MinFraud::Model::Score;
 use WebService::MinFraud::Model::Chargeback;
-use WebService::MinFraud::Types
-    qw( JSONObject MaxMindID MaxMindLicenseKey Str URIObject UserAgentObject );
+use WebService::MinFraud::Types qw(
+    JSONObject
+    MaxMindID
+    Str
+    URIObject
+    UserAgentObject
+);
 use WebService::MinFraud::Validator;
 
 with 'WebService::MinFraud::Role::HasLocales';
@@ -56,7 +61,7 @@ has _json => (
 );
 has license_key => (
     is       => 'ro',
-    isa      => MaxMindLicenseKey,
+    isa      => Defined,
     required => 1,
 );
 
@@ -342,7 +347,7 @@ WebService::MinFraud::Client - Perl API for MaxMind's minFraud Score and Insight
 
 =head1 VERSION
 
-version 1.009001
+version 1.010000
 
 =head1 SYNOPSIS
 
@@ -633,7 +638,7 @@ Mateu Hunter <mhunter@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 - 2019 by MaxMind, Inc.
+This software is copyright (c) 2015 - 2020 by MaxMind, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
